@@ -145,6 +145,7 @@ class LauncherDebugAdapterProtocol(DebugAdapterProtocol):
         dryRun: Optional[bool] = None,
         mode: Optional[str] = None,
         variableFiles: Optional[List[str]] = None,
+        languages: Optional[List[str]] = None,
         arguments: Optional[LaunchRequestArguments] = None,
         *_args: Any,
         **_kwargs: Any,
@@ -184,6 +185,10 @@ class LauncherDebugAdapterProtocol(DebugAdapterProtocol):
 
         run_args += ["--"]
 
+        if languages:
+            for lang in languages:
+                run_args += ["--language", lang]
+
         if mode:
             if mode == "rpa":
                 run_args += ["--rpa"]
