@@ -82,6 +82,7 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
         super().__init__(protocol)
 
         self.workspace_loaded_event = Event()
+
         self._workspace_load_lock = Lock()
         self._workspace_loaded = False
 
@@ -90,9 +91,8 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
         ] = {}
 
         self._current_workspace_task: Optional[asyncio.Task[WorkspaceDiagnosticReport]] = None
-        self.in_get_document_diagnostics = Event(True)
+
         self.in_get_workspace_diagnostics = Event(True)
-        self._collect_full_diagnostics = False
 
     def extend_capabilities(self, capabilities: ServerCapabilities) -> None:
         if (
@@ -102,22 +102,13 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
         ):
             capabilities.diagnostic_provider = DiagnosticOptions(
                 inter_file_dependencies=True,
-                workspace_diagnostics=False,
+                workspace_diagnostics=True,
                 identifier=f"robotcodelsp_{uuid.uuid4()}",
                 work_done_progress=True,
             )
 
-    @property
-    def collect_full_diagnostics(self) -> bool:
-        return self._collect_full_diagnostics
-
-    async def set_collect_full_diagnostics(self, value: bool) -> None:
-        if self._collect_full_diagnostics != value:
-            self._collect_full_diagnostics = value
-            await self.refresh()
-
     @async_tasking_event_iterator
-    async def collect(sender, document: TextDocument, full: bool) -> DiagnosticsResult:  # NOSONAR
+    async def collect(sender, document: TextDocument) -> DiagnosticsResult:  # NOSONAR
         ...
 
     @async_tasking_event
@@ -159,8 +150,6 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
                         await self.on_workspace_loaded(self)
 
     async def get_document_diagnostics(self, document: TextDocument) -> RelatedFullDocumentDiagnosticReport:
-        if self.collect_full_diagnostics:
-            return await document.get_cache(self.__get_full_document_diagnostics)
         return await document.get_cache(self.__get_document_diagnostics)
 
     async def __get_document_diagnostics(self, document: TextDocument) -> RelatedFullDocumentDiagnosticReport:
@@ -169,29 +158,7 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
         diagnostics: List[Diagnostic] = []
 
         async for result_any in self.collect(
-            self,
-            document,
-            full=False,
-            callback_filter=language_id_filter(document),
-            return_exceptions=True,
-        ):
-            result = cast(DiagnosticsResult, result_any)
-
-            if isinstance(result, BaseException):
-                if not isinstance(result, asyncio.CancelledError):
-                    self._logger.exception(result, exc_info=result)
-            else:
-                diagnostics.extend(result.diagnostics or [])
-
-        return RelatedFullDocumentDiagnosticReport(items=diagnostics, result_id=str(uuid.uuid4()))
-
-    async def __get_full_document_diagnostics(self, document: TextDocument) -> RelatedFullDocumentDiagnosticReport:
-        await self.ensure_workspace_loaded()
-
-        diagnostics: List[Diagnostic] = []
-
-        async for result_any in self.collect(
-            self, document, full=True, callback_filter=language_id_filter(document), return_exceptions=True
+            self, document, callback_filter=language_id_filter(document), return_exceptions=True
         ):
             result = cast(DiagnosticsResult, result_any)
 
@@ -215,18 +182,14 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
     ) -> DocumentDiagnosticReport:
         self._logger.debug(lambda: f"textDocument/diagnostic for {text_document}")
 
-        self.in_get_document_diagnostics.clear()
-
         try:
-            await self.ensure_workspace_loaded()
-
             document = await self.parent.documents.get(text_document.uri)
             if document is None:
                 raise JsonRPCErrorException(ErrorCodes.INVALID_PARAMS, f"Document {text_document!r} not found")
 
-            async def _get_diagnostics() -> Optional[RelatedFullDocumentDiagnosticReport]:
+            async def _get_diagnostics(doc: TextDocument) -> Optional[RelatedFullDocumentDiagnosticReport]:
                 if document is not None:
-                    return await self.get_document_diagnostics(document)
+                    return await self.get_document_diagnostics(doc)
 
                 return None
 
@@ -234,7 +197,7 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
                 self._logger.debug(lambda: f"textDocument/diagnostic cancel old task {text_document}")
                 self._current_document_tasks[document].cancel()
 
-            task = create_sub_task(_get_diagnostics())
+            task = create_sub_task(_get_diagnostics(document))
             self._current_document_tasks[document] = task
 
             try:
@@ -242,12 +205,9 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
                 if result is None:
                     raise RuntimeError("Unexpected result.")
 
-            except asyncio.CancelledError as e:
+            except asyncio.CancelledError:
                 self._logger.debug(lambda: f"textDocument/diagnostic canceled {text_document}")
-
-                raise JsonRPCErrorException(
-                    ErrorCodes.SERVER_CANCELLED, "Cancelled", data=DiagnosticServerCancellationData(True)
-                ) from e
+                raise
             finally:
                 if document in self._current_document_tasks and self._current_document_tasks[document] == task:
                     del self._current_document_tasks[document]
@@ -257,7 +217,7 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
 
             return result
         finally:
-            self.in_get_document_diagnostics.set()
+
             await self.on_document_diagnostics_ended(self)
 
             self._logger.debug(lambda: f"textDocument/diagnostic ready  {text_document}")
@@ -299,12 +259,14 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
 
         async def _get_partial_diagnostics() -> WorkspaceDiagnosticReport:
             async with self.parent.window.progress(
-                f"Analyse {'full ' if self.collect_full_diagnostics else ''} Workspace",
+                "Analyse Workspace",
                 progress_token=work_done_token,
                 cancellable=False,
             ) as progress:
 
                 async def _task(doc: TextDocument) -> None:
+                    if doc.opened_in_editor:
+                        return
 
                     if await self.get_analysis_progress_mode(doc.uri) == AnalysisProgressMode.DETAILED:
                         path = doc.uri.to_path()
@@ -314,7 +276,7 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
                         else:
                             name = path.relative_to(folder.uri.to_path())
 
-                        progress.report(f"Analyse {'full ' if self.collect_full_diagnostics else ''} {name}")
+                        progress.report(f"Analyse {name}")
 
                     doc_result = await self.get_document_diagnostics(doc)
 
@@ -346,11 +308,11 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
                         )
 
                 for doc in self.parent.documents.documents:
-                    await _task(doc)
+                    if await self.get_diagnostics_mode(doc.uri) == DiagnosticsMode.WORKSPACE:
+                        await _task(doc)
 
                 return WorkspaceDiagnosticReport(items=[])
 
-        await self.in_get_document_diagnostics.wait()
         self.in_get_workspace_diagnostics.clear()
         try:
             await self.ensure_workspace_loaded()
@@ -361,14 +323,16 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
             task = create_sub_task(_get_diagnostics() if partial_result_token is None else _get_partial_diagnostics())
             self._current_workspace_task = task
             try:
-                result = await task
-                await self.set_collect_full_diagnostics(True)
-                return result
-            except asyncio.CancelledError as e:
+                return await task
+            except asyncio.CancelledError:
                 self._logger.debug("workspace/diagnostic canceled")
-                raise JsonRPCErrorException(
-                    ErrorCodes.SERVER_CANCELLED, "ServerCancelled", data=DiagnosticServerCancellationData(True)
-                ) from e
+                if self._current_workspace_task is None:
+                    raise JsonRPCErrorException(
+                        ErrorCodes.SERVER_CANCELLED,
+                        "ServerCancelled",
+                        data=DiagnosticServerCancellationData(True),
+                    )
+                raise
             finally:
                 if self._current_workspace_task == task:
                     self._current_workspace_task = None
@@ -377,15 +341,17 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
             self.in_get_workspace_diagnostics.set()
             await self.on_workspace_diagnostics_ended(self)
 
-    def cancel_workspace_diagnostics(self) -> None:
+    async def cancel_workspace_diagnostics(self) -> None:
         if self._current_workspace_task is not None and not self._current_workspace_task.done():
-            self._current_workspace_task.cancel()
+            task = self._current_workspace_task
+            self._current_workspace_task = None
+            task.get_loop().call_soon_threadsafe(task.cancel)
 
-    def cancel_document_diagnostics(self, document: TextDocument) -> None:
+    async def cancel_document_diagnostics(self, document: TextDocument) -> None:
         task = self._current_document_tasks.get(document, None)
         if task is not None:
             self._logger.critical(lambda: f"textDocument/diagnostic canceled {document}")
-            task.cancel()
+            task.get_loop().call_soon_threadsafe(task.cancel)
 
     async def get_analysis_progress_mode(self, uri: Uri) -> AnalysisProgressMode:
         for e in await self.on_get_analysis_progress_mode(self, uri):
