@@ -48,7 +48,7 @@ class RobotConfig(ConfigBase):
 @config_section("robotcode.syntax")
 @dataclass
 class SyntaxConfig(ConfigBase):
-    section_style: str = "*** {name}s ***"
+    section_style: Optional[str] = None
 
 
 @config_section("robotcode.robocop")
@@ -78,7 +78,8 @@ class AnalysisConfig(ConfigBase):
     diagnostic_mode: DiagnosticsMode = DiagnosticsMode.OPENFILESONLY
     progress_mode: AnalysisProgressMode = AnalysisProgressMode.SIMPLE
     max_project_file_count: int = 1000
-    references_code_lens: bool = True
+    references_code_lens: bool = False
+    find_unused_references: bool = False
 
 
 @config_section("robotcode")
