@@ -111,11 +111,7 @@ class RobotCodeLensProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixi
         name = code_lens.data["name"]
         line = code_lens.data["line"]
 
-        if (
-            self.parent.diagnostics.workspace_loaded_event.is_set()
-            and self.parent.diagnostics.in_get_workspace_diagnostics.is_set()
-            and self.parent.diagnostics.in_get_document_diagnostics.is_set()
-        ):
+        if self.parent.diagnostics.workspace_loaded_event.is_set():
             kw_doc = await self.get_keyword_definition_at_line(namespace, name, line)
 
             if kw_doc is not None and not kw_doc.is_error_handler:
