@@ -37,6 +37,7 @@ from ...common.text_document import TextDocument
 from ..diagnostics.library_doc import (
     ALL_RUN_KEYWORDS_MATCHERS,
     BUILTIN_LIBRARY_NAME,
+    KeywordArgumentKind,
     KeywordDoc,
     KeywordMatcher,
     LibraryDoc,
@@ -92,6 +93,7 @@ class RobotSemTokenTypes(Enum):
     NAMESPACE = "namespace"
     ERROR = "error"
     CONFIG = "config"
+    NAMED_ARGUMENT = "namedArgument"
 
 
 class RobotSemTokenModifiers(Enum):
@@ -177,7 +179,7 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
             frozenset({RobotToken.VARIABLE, RobotToken.ASSIGN}): (RobotSemTokenTypes.VARIABLE, None),
             frozenset({RobotToken.KEYWORD}): (RobotSemTokenTypes.KEYWORD, None),
             frozenset({ROBOT_KEYWORD_INNER}): (RobotSemTokenTypes.KEYWORD_INNER, None),
-            frozenset({ROBOT_NAMED_ARGUMENT}): (RobotSemTokenTypes.VARIABLE, None),
+            frozenset({ROBOT_NAMED_ARGUMENT}): (RobotSemTokenTypes.NAMED_ARGUMENT, None),
             frozenset({ROBOT_OPERATOR}): (SemanticTokenTypes.OPERATOR, None),
             frozenset({RobotToken.NAME}): (RobotSemTokenTypes.NAME, None),
             frozenset({RobotToken.CONTINUATION}): (RobotSemTokenTypes.CONTINUATION, None),
@@ -253,6 +255,7 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
     ) -> AsyncGenerator[SemTokenInfo, None]:
         from robot.parsing.lexer.tokens import Token as RobotToken
         from robot.parsing.model.statements import (
+            Arguments,
             Documentation,
             Fixture,
             LibraryImport,
@@ -282,7 +285,13 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
                     if last_index >= 0:
                         yield SemTokenInfo(token.lineno, col_offset, 2, RobotSemTokenTypes.VARIABLE_BEGIN, sem_mod)
 
-                        yield SemTokenInfo.from_token(token, sem_type, sem_mod, col_offset + 2, last_index - 2)
+                        yield SemTokenInfo.from_token(
+                            token,
+                            SemanticTokenTypes.PARAMETER if isinstance(node, Arguments) else sem_type,
+                            sem_mod,
+                            col_offset + 2,
+                            last_index - 2,
+                        )
 
                         yield SemTokenInfo(
                             token.lineno, col_offset + last_index, 1, RobotSemTokenTypes.VARIABLE_END, sem_mod
@@ -313,36 +322,37 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
             elif token.type in [RobotToken.KEYWORD, ROBOT_KEYWORD_INNER] or (
                 token.type == RobotToken.NAME and isinstance(node, (Fixture, Template, TestTemplate))
             ):
-                bdd_len = 0
+                if await namespace.find_keyword(token.value, raise_keyword_error=False, handle_bdd_style=False) is None:
+                    bdd_len = 0
 
-                if get_robot_version() < (5, 1):
-                    bdd_match = cls.BDD_TOKEN_REGEX.match(token.value)
-                    if bdd_match:
-                        bdd_len = len(bdd_match.group(1))
-                else:
-                    parts = token.value.split(maxsplit=1)
-                    if len(parts) == 2:
-                        prefix, _ = parts
-                        if prefix.title() in (
-                            namespace.languages.bdd_prefixes
-                            if namespace.languages is not None
-                            else {"Given ", "When ", "Then ", "And ", "But "}
-                        ):
-                            bdd_len = len(prefix)
+                    if get_robot_version() < (5, 1):
+                        bdd_match = cls.BDD_TOKEN_REGEX.match(token.value)
+                        if bdd_match:
+                            bdd_len = len(bdd_match.group(1))
+                    else:
+                        parts = token.value.split(maxsplit=1)
+                        if len(parts) == 2:
+                            prefix, _ = parts
+                            if prefix.title() in (
+                                namespace.languages.bdd_prefixes
+                                if namespace.languages is not None
+                                else {"Given ", "When ", "Then ", "And ", "But "}
+                            ):
+                                bdd_len = len(prefix)
 
-                if bdd_len > 0:
-                    yield SemTokenInfo.from_token(
-                        token, RobotSemTokenTypes.BDD_PREFIX, sem_mod, token.col_offset, bdd_len
-                    )
-                    yield SemTokenInfo.from_token(token, sem_type, sem_mod, token.col_offset + bdd_len, 1)
+                    if bdd_len > 0:
+                        yield SemTokenInfo.from_token(
+                            token, RobotSemTokenTypes.BDD_PREFIX, sem_mod, token.col_offset, bdd_len
+                        )
+                        yield SemTokenInfo.from_token(token, sem_type, sem_mod, token.col_offset + bdd_len, 1)
 
-                    token = RobotToken(
-                        token.type,
-                        token.value[bdd_len + 1 :],
-                        token.lineno,
-                        token.col_offset + bdd_len + 1,
-                        token.error,
-                    )
+                        token = RobotToken(
+                            token.type,
+                            token.value[bdd_len + 1 :],
+                            token.lineno,
+                            token.col_offset + bdd_len + 1,
+                            token.error,
+                        )
 
                 if col_offset is None:
                     col_offset = token.col_offset
@@ -663,7 +673,9 @@ class RobotSemanticTokenProtocolPart(RobotLanguageServerProtocolPart, ModelHelpe
                     if kw_doc is None:
                         kw_doc = await namespace.find_keyword(kw_token.value)
 
-                    if kw_doc and any(v for v in kw_doc.args if v.name == name):
+                    if kw_doc and any(
+                        v for v in kw_doc.args if v.kind == KeywordArgumentKind.VAR_NAMED or v.name == name
+                    ):
                         length = len(name)
                         yield RobotToken(ROBOT_NAMED_ARGUMENT, name, token.lineno, token.col_offset), node
 
